==> zzyj-financeintegration-api-3.0.0-20220519.081907-17-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMJJFVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMJJFVO implements Serializable {

    private static final long serialVersionUID = -6550871832456894273L;

    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 项目ID
     */
    private String projectId;

    private String period;

    private BigDecimal costMny;

    private String cwFlag;
    public PMJJFVO() {
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public String getCwFlag() {
        return cwFlag;
    }

    public void setCwFlag(String cwFlag) {
        this.cwFlag = cwFlag;
    }

    @Override
    public String toString() {
        return "PMJJFVO{" +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", projectId='" + projectId + '\'' +
                ", period='" + period + '\'' +
                ", costMny='" + costMny + '\'' +
                ", cwFlag='" + cwFlag + '\'' +
                '}';
    }
}

==> zzyj-financeintegration-api-3.0.0-20250912.021445-121-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMJJFVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMJJFVO implements Serializable {

    private static final long serialVersionUID = -6550871832456894273L;

    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 项目ID
     */
    private String projectId;

    private String period;

    private BigDecimal costMny;

    private String cwFlag;

    private String fymc;

    public PMJJFVO() {
    }

    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public String getCwFlag() {
        return cwFlag;
    }

    public void setCwFlag(String cwFlag) {
        this.cwFlag = cwFlag;
    }

    @Override
    public String toString() {
        return "PMJJFVO{" +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", projectId='" + projectId + '\'' +
                ", period='" + period + '\'' +
                ", costMny='" + costMny + '\'' +
                ", cwFlag='" + cwFlag + '\'' +
                '}';
    }
}
